import type { ResolvedModule } from '@callstack/polygen-project';
import { W2CExternModule, W2CGeneratedModule } from './modules.js';
import type { ResolvedModuleImport } from './types.js';
/**
 * Holds aggregate codegen state.
 *
 * Contains methods to progressively build the codegen state.
 */
export declare class CodegenContext {
    /**
     * List of generated modules
     */
    modules: W2CGeneratedModule[];
    /**
     * List of imported modules
     *
     * Generated by processing imports of generated modules
     */
    importedModules: Map<string, W2CExternModule>;
    /**
     * Adds a module to the context.
     *
     * This method should be used to add new modules to the context.
     * Before creating a new W2CModule, module body is scanned for imports and
     * all imported modules are added to the context into `importedModules`.
     *
     * This way, when creating the module, all imported modules can be resolved.
     */
    addModule(module: ResolvedModule): Promise<[W2CGeneratedModule, W2CExternModule[]]>;
    /**
     * Gets an imported module by name.
     *
     * If the module is not found, an error is thrown.
     *
     * @param name Name of the imported module
     */
    getImportedModule(name: string): W2CExternModule;
    /**
     * Gets or creates an imported module by name.
     *
     * If the module is not found, an empty one is created.
     *
     * @param name Name of the imported module
     */
    getOrCreatedImportedModule(name: string): W2CExternModule;
    resolveImport(moduleName: string, symbolName: string): ResolvedModuleImport | undefined;
    private processImportedModules;
}
//# sourceMappingURL=context.d.ts.map