import type { ModuleEntity, ModuleExport, ModuleGlobal, ModuleImport, ModuleMemory, ModuleTable, ValueType } from '@callstack/wasm-parser';
import type { W2CModuleBase } from './modules.js';
import type { GeneratedEntity, GeneratedModuleFunction, GeneratedSymbol } from './types.js';
export declare function mangleSymbolName(name: string, mangledModule: string): string;
/**
 * Creates GeneratedEntity from ModuleEntity
 *
 * Only functions are augmented at the moment.
 *
 * @param entity Raw ModuleEntity
 */
export declare function processEntity(entity: ModuleEntity): GeneratedEntity;
/**
 * Builds a GeneratedSymbol from ModuleImport or ModuleExport.
 *
 * @param module
 * @param entity
 */
export declare function buildGeneratedSymbol(module: W2CModuleBase, entity: ModuleImport | ModuleExport): GeneratedSymbol;
export interface SymbolMatchHandler<TResult = void> {
    func: (func: GeneratedSymbol<GeneratedModuleFunction>) => TResult;
    global: (global: GeneratedSymbol<ModuleGlobal>) => TResult;
    table: (table: GeneratedSymbol<ModuleTable>) => TResult;
    memory: (memory: GeneratedSymbol<ModuleMemory>) => TResult;
}
/**
 * Matches a GeneratedSymbol to a handler based on its kind.
 *
 * Throws `SymbolMatchError` if the kind is unknown.
 *
 * @param symbol Symbol to match
 * @param matcher Handler to match the symbol based on its type
 */
export declare function matchSymbol<TResult = void>(symbol: GeneratedSymbol, matcher: SymbolMatchHandler<TResult>): TResult;
export declare function matchW2CRType(t?: ValueType): string;
//# sourceMappingURL=utils.d.ts.map