import { mangleName } from '../wasm2c/mangle.js';
export function mangleSymbolName(name, mangledModule) {
    return `w2c_${mangledModule}_${mangleName(name)}`;
}
/**
 * Creates GeneratedEntity from ModuleEntity
 *
 * Only functions are augmented at the moment.
 *
 * @param entity Raw ModuleEntity
 */
export function processEntity(entity) {
    switch (entity.kind) {
        case 'function':
            const returnType = matchW2CRType(entity.resultTypes[0]);
            return {
                ...entity,
                parameterTypeNames: entity.parametersTypes.map(matchW2CRType),
                returnTypeName: returnType,
            };
        default:
            return entity;
    }
}
/**
 * Builds a GeneratedSymbol from ModuleImport or ModuleExport.
 *
 * @param module
 * @param entity
 */
export function buildGeneratedSymbol(module, entity) {
    const accessorName = mangleSymbolName(entity.name, module.mangledName);
    return {
        localName: entity.name,
        mangledLocalName: mangleName(entity.name),
        functionSymbolAccessorName: accessorName,
        module,
        target: processEntity(entity.target),
    };
}
class SymbolMatchError extends Error {
    constructor(kind) {
        super(`Unknown import type ${kind}`);
        this.kind = kind;
    }
}
/**
 * Matches a GeneratedSymbol to a handler based on its kind.
 *
 * Throws `SymbolMatchError` if the kind is unknown.
 *
 * @param symbol Symbol to match
 * @param matcher Handler to match the symbol based on its type
 */
export function matchSymbol(symbol, matcher) {
    switch (symbol.target.kind) {
        case 'function':
            return matcher.func(symbol);
        case 'global':
            return matcher.global(symbol);
        case 'memory':
            return matcher.memory(symbol);
        case 'table':
            return matcher.table(symbol);
        default:
            // @ts-ignore
            throw new SymbolMatchError(symbol.target.kind);
    }
}
// TODO: workaround a bug(?) that all types are returned as either none, u32 or f64
export function matchW2CRType(t) {
    if (!t) {
        return 'void';
    }
    // TODO: figure out why wasm2c returns u32 for number types sometimes
    if (t.startsWith('i')) {
        return t.replace(/^i/, 'u');
    }
    return t;
}
