import type { FunctionBuilder, VariableBuilder } from './builder.decls.js';
import { type TypeAction } from './builder.types.js';
import type { BuilderAction } from './common.js';
import { SourceWriter } from './source-writer.js';
export declare class SourceBuilderError extends Error {
    constructor(message: string);
}
export declare class SourceBlockBuilder {
    protected writer: SourceWriter;
    readonly isHeader: boolean;
    constructor(isHeader: boolean, writer?: SourceWriter);
    /**
     * Returns the generated source code as a string.
     */
    toString(): string;
    /**
     * Adds vertical spacing to the source code.
     *
     * @param lines
     */
    spacing(lines?: number): this;
    /**
     * Helper function to generate a type.
     *
     * @param builder Function that builds a type
     * @return C++ Type as string
     */
    type(builder: TypeAction): string;
    /**
     * Inserts generated code for each element in the array using custom generator.
     *
     * @param elements
     * @param generator
     */
    writeManyLines<T>(elements: T[], generator: (element: T, builder: SourceBlockBuilder) => string): this;
    /**
     * Adds a using namespace directive.
     * @param name Namespace to use
     */
    usingNamespace(name: string): this;
    using(name: string, value: string): this;
    return_(target: string): this;
    namespace(name: string, action: BuilderAction<SourceBlockBuilder>): this;
    defineFunction(builder: FunctionBuilder): this;
    defineVariable(builder: VariableBuilder): this;
    insertRaw(source: string): this;
}
//# sourceMappingURL=builder.block.d.ts.map