import { SourceBlockBuilder } from './builder.block.js';
import { ExpressionBuilder, exprs, } from './builder.expr.js';
import { TypeBuilder, types } from './builder.types.js';
export class FunctionBuilder {
    constructor(name, returnTypeBuilder, parameters = []) {
        this.returnType = 'void';
        this.parameters = [];
        this.name = name;
        this.returnType = returnTypeBuilder?.toString() ?? 'void';
        this.parameters = parameters;
    }
    withReturnType(type) {
        if (type instanceof TypeBuilder) {
            this.returnType = type.toString();
        }
        else {
            this.returnType = type(types).toString();
        }
        return this;
    }
    addParameter(block) {
        this.parameters.push(block);
        return this;
    }
    withBody(block) {
        this.bodyAction = block;
        return this;
    }
    build(writer) {
        writer.write(`${this.returnType} ${this.name}`);
        writer.write('(');
        writer.writeCommaList(this.parameters, (param) => `${param.type} ${param.name}`);
        writer.write(')');
        if (this.bodyAction) {
            writer.writeLine('{');
            writer.withIndent(() => {
                this.bodyAction(new SourceBlockBuilder(false, writer));
            });
            writer.writeLine('}');
        }
        else {
            writer.writeLine(';');
        }
    }
}
export class VariableBuilder {
    constructor(name, typeBuilder) {
        this.initializerMultiline = false;
        this._name = name;
        this._type = typeBuilder ?? types.auto;
    }
    get name() {
        return this._name;
    }
    get type() {
        return new TypeBuilder(this._type.toString());
    }
    withName(name) {
        this._name = name;
        return this;
    }
    withType(type) {
        if (type instanceof TypeBuilder) {
            this._type = type;
        }
        else {
            this._type = type(types);
        }
        return this;
    }
    withInitializer(expressionBuilder, multiLine = false) {
        if (expressionBuilder instanceof ExpressionBuilder) {
            this.expressionBuilder = expressionBuilder;
        }
        else {
            this.expressionBuilder = expressionBuilder(exprs);
        }
        this.initializerMultiline = multiLine;
        return this;
    }
    build(writer) {
        writer.write(`${this._type.toString()} ${this._name}`);
        if (this.expressionBuilder) {
            writer.write(' { ');
            if (this.initializerMultiline) {
                writer.writeLine('');
                writer.withIndent(() => {
                    this.expressionBuilder.build(writer);
                });
                writer.writeLine('');
            }
            else {
                this.expressionBuilder.build(writer);
            }
            writer.write(' }');
        }
        writer.write(';');
    }
}
