import { SourceBlockBuilder, SourceBuilderError } from './builder.block.js';
export class SourceFileBuilder extends SourceBlockBuilder {
    constructor(isHeader, writer) {
        super(isHeader, writer);
    }
    //
    // ------------------------------------------------------------------------------------------ C++ STATEMENTS
    //
    writeIncludeGuard() {
        if (!this.isHeader) {
            throw new SourceBuilderError('Cannot add include guard to source file');
        }
        this.writer.writeLine(`#pragma once`);
        return this;
    }
    /**
     * Adds an include preprocesor directive.
     *
     * @param path Path to include
     * @param local Whenever to use local include or a system include
     */
    include(path, local) {
        if (local) {
            this.writer.writeLine(`#include "${path}"`);
        }
        else {
            this.writer.writeLine(`#include <${path}>`);
        }
        return this;
    }
    /**
     * Adds a local include preprocesor directive.
     *
     * @param path Path to include
     */
    includeLocal(path) {
        return this.include(path, true);
    }
    /**
     * Adds a system include preprocesor directive.
     *
     * @param path Path to include
     */
    includeSystem(path) {
        return this.include(path, false);
    }
}
