export const types = {
    get auto() {
        return new TypeBuilder('auto');
    },
    get string() {
        return new TypeBuilder('std::string');
    },
    get stringVector() {
        return this.string.asVector();
    },
    of(name) {
        return new TypeBuilder(name);
    },
    function(returnType, args) {
        const argsStr = args.map((a) => a.toString());
        const returnTypeStr = returnType.toString();
        return new TypeBuilder(`std::function<${returnTypeStr}(${argsStr.join(', ')})>`);
    },
    map(key, value) {
        return new TypeBuilder(`std::unordered_map<${key.toString()}, ${value.toString()}>`);
    },
};
export class TypeBuilder {
    constructor(type) {
        this.type = type;
    }
    build(writer) {
        writer.write(this.type);
    }
    toString() {
        return this.type;
    }
    asVector() {
        return new TypeBuilder(`std::vector<${this.type}>`);
    }
    asSharedPtr() {
        return new TypeBuilder(`std::shared_ptr<${this.type}>`);
    }
    asConst() {
        return new TypeBuilder(`const ${this.type}`);
    }
    asRef() {
        return new TypeBuilder(`${this.type}&`);
    }
    asConstRef() {
        return new TypeBuilder(`const ${this.type}&`);
    }
    asPtr() {
        return new TypeBuilder(`${this.type}*`);
    }
    asConstPtr() {
        return new TypeBuilder(`const ${this.type}*`);
    }
}
