import { SourceWriter } from "./source-writer.js";
interface Builder {
    toString(): string;
}
type BuilderAction<T> = (builder: T) => Builder;
export declare class SourceBuilderError extends Error {
    constructor(message: string);
}
export declare class SourceBuilder {
    protected writer: SourceWriter;
    readonly isHeader: boolean;
    constructor(isHeader: boolean, writer?: SourceWriter);
    /**
     * Returns the generated source code as a string.
     */
    toString(): string;
    /**
     * Adds vertical spacing to the source code.
     *
     * @param lines
     */
    spacing(lines?: number): this;
    /**
     * Helper function to generate a type.
     *
     * @param builder Function that builds a type
     * @return C++ Type as string
     */
    type(builder: TypeBuilder): string;
    /**
     * Inserts generated code for each element in the array using custom generator.
     *
     * @param elements
     * @param generator
     */
    insertGenerated<T>(elements: T[], generator: (element: T, builder: SourceBuilder) => string): this;
    /**
     * Adds a using namespace directive.
     * @param name Namespace to use
     */
    usingNamespace(name: string): this;
    using(name: string, value: string): this;
    namespace(name: string, block: BuilderAction<this>): this;
    function(name: string, block: BuilderAction<this>): this;
}
export declare class SourceFileBuilder extends SourceBuilder {
    constructor(writer?: SourceWriter);
    writeIncludeGuard(): this;
    /**
     * Adds an include preprocesor directive.
     *
     * @param path Path to include
     * @param local Whenever to use local include or a system include
     */
    private include;
    /**
     * Adds a local include preprocesor directive.
     *
     * @param path Path to include
     */
    includeLocal(path: string): this;
    /**
     * Adds a system include preprocesor directive.
     *
     * @param path Path to include
     */
    includeSystem(path: string): this;
}
export {};
//# sourceMappingURL=cpp.d.ts.map