/**
 * SourceWriter is a helper class to build source code strings with proper indentation.
 */
export declare class SourceWriter {
    /**
     * Current indentation level.
     */
    indentLevel: number;
    /**
     * Current indentation size
     */
    readonly indentSize: number;
    private source;
    constructor(indentLevel?: number, indentSize?: number);
    /**
     * Write a string to the source code.
     *
     * @param str String to write
     */
    write(str: string): this;
    /**
     * Write a line to the source code.
     *
     * @param line Line to write
     */
    writeLine(line: string): this;
    /**
     * Write multiple items to the source code.
     *
     * @param elements Elements to write
     * @param builder Builder function to generate the line for each element
     * @param joiner How to join the generated elements
     */
    writeMany<T>(elements: T[], builder: (element: T, writer: SourceWriter) => string | unknown, joiner: string): this;
    /**
     * Write a list of elements separated by a comma.
     *
     * @param elements Elements to write
     * @param builder Builder function to generate the source for each element
     */
    writeCommaList<T>(elements: T[], builder: (element: T, writer: SourceWriter) => string | unknown): this;
    /**
     * Increase the indentation level.
     */
    pushIndent(): this;
    /**
     * Decrease the indentation level.
     */
    popIndent(): this;
    /**
     * Write a block of code with increased indentation.
     *
     * @param cb Callback to use to write the indented block
     */
    withIndent(cb: () => void): this;
    /**
     * Returns the generated source code as a string.
     */
    toString(): string;
    private indentString;
    private get isFreshLine();
}
//# sourceMappingURL=source-writer.d.ts.map