import type { GeneratedImport } from '../types.js';
import { W2CCodegenLocalImportedModule } from './codegen-context.js';
import { W2CModuleContext } from './context.js';
/**
 * Represents an imported module in the shared context.
 *
 * This represents an imported module with imported symbols across all generated modules.
 */
export declare class W2CImportedModule {
    /**
     * Information about the imported module
     */
    private readonly moduleInfo;
    /**
     * All imported symbols from this module, across all generated modules.
     */
    readonly imports: GeneratedImport[];
    constructor(moduleInfo: W2CCodegenLocalImportedModule, imports: GeneratedImport[]);
    /**
     * Name of the imported module.
     */
    get name(): string;
    /**
     * Mangled name of the imported module.
     */
    get managedName(): string;
    /**
     * Gets the C typename that was generated by wasm2c for this imported module.
     */
    get generatedRootContextFieldName(): string;
    /**
     * Gets the name of field of root context struct, that was generated by wasm2c for this imported module.
     */
    get generatedContextTypeName(): string;
}
export declare class W2CSharedContext {
    readonly modules: W2CModuleContext[];
    readonly importedModules: W2CImportedModule[];
    constructor(modules: W2CModuleContext[]);
}
//# sourceMappingURL=shared.d.ts.map