/**
 * Represents an imported module in the shared context.
 *
 * This represents an imported module with imported symbols across all generated modules.
 */
export class W2CImportedModule {
    constructor(moduleInfo, imports) {
        this.moduleInfo = moduleInfo;
        this.imports = imports;
    }
    /**
     * Name of the imported module.
     */
    get name() {
        return this.moduleInfo.name;
    }
    /**
     * Mangled name of the imported module.
     */
    get managedName() {
        return this.moduleInfo.name;
    }
    /**
     * Gets the C typename that was generated by wasm2c for this imported module.
     */
    get generatedRootContextFieldName() {
        return this.moduleInfo.generatedRootContextFieldName;
    }
    /**
     * Gets the name of field of root context struct, that was generated by wasm2c for this imported module.
     */
    get generatedContextTypeName() {
        return this.moduleInfo.generatedContextTypeName;
    }
}
export class W2CSharedContext {
    constructor(modules) {
        this.modules = modules;
        this.importedModules = processImportedModules(this.modules);
    }
}
function processImportedModules(modules) {
    const allImports = modules.flatMap((module) => module.codegen.imports);
    const importsGroupedByName = Object.groupBy(allImports, (el) => el.moduleInfo.name);
    const nameToInfoMap = Object.groupBy(allImports.map((el) => el.moduleInfo), (el) => el.name);
    return Object.entries(importsGroupedByName)
        .map(([moduleName, imports]) => {
        const info = nameToInfoMap[moduleName]?.[0];
        if (!info) {
            throw new Error(`Could not find info for module ${moduleName}`);
        }
        return new W2CImportedModule(info, imports ?? []);
    })
        .filter(Boolean);
}
