/**
 * Error class for wasm2c validation errors.
 */
export declare class Wasm2cError extends Error {
    constructor(message: string);
}
/**
 * Validates the presence of the `wasm2c` binary.
 *
 * Binary is searched in `PATH` and in `WABT_PATH` environment variable.
 * If not found, an error message is logged indicating the missing configuration,
 * and the process exits with a failure code.
 *
 * @return No value is returned from this function.
 */
export declare function ensureBinaryAvailable(): Promise<void>;
/**
 * Options for the wasm2c generation process.
 */
export interface Wasm2cGenerateOptions {
    /**
     * The name of the generated module.
     */
    moduleName?: string;
    /**
     * Overrides the number of outputs for the module.
     */
    numOutputs?: number;
}
/**
 * Returns the output files for a given configuration.
 *
 * @param inputFile Path to the input WASM module
 * @param outputDir Path to the directory containing the output files
 * @param options Optional configuration for the generation process
 */
export declare function getOutputFilesFor(inputFile: string, outputDir: string, options?: Wasm2cGenerateOptions): string[];
/**
 * Generates C source files from a given WebAssembly input file.
 *
 * @param inputPath The path to the WebAssembly (.wasm) input file.
 * @param outputDir Directory path where the generated C source file will be saved.
 * @param options Optional configuration for the generation process, including the module name.
 * @return A promise that resolves once the C source file generation is complete.
 */
export declare function generateCSources(inputPath: string, outputDir: string, options?: Wasm2cGenerateOptions): Promise<string[]>;
//# sourceMappingURL=wasm2c.d.ts.map